@@ -6,6 +6,7 @@ use realm_syscall::new_udp_socket;
 
 use crate::endpoint::ConnectOpts;
 
+#[allow(clippy::clone_on_copy)]
 pub fn bind(laddr: &SocketAddr) -> Result<UdpSocket> {
     let socket = new_udp_socket(laddr)?;
 
@@ -20,11 +21,13 @@ pub fn bind(laddr: &SocketAddr) -> Result<UdpSocket> {
 pub async fn associate(raddr: &SocketAddr, conn_opts: &ConnectOpts) -> Result<UdpSocket> {
     let ConnectOpts {
         bind_address,
+
+        #[cfg(target_os = "linux")]
         bind_interface,
         ..
     } = conn_opts;
 
-    let socket = new_udp_socket(&raddr)?;
+    let socket = new_udp_socket(raddr)?;
 
     // ignore error
     let _ = socket.set_reuse_address(true);
